import { 
  select, 
  csv, 
  scaleLinear,  
  max, 
  axisLeft,
  axisBottom,
  format,
  extent
} from 'd3';

const svg = select('svg');
const height = +svg.attr('height');
const width = parseFloat(svg.attr('width')); 

const render = (data) => {
  const title = "Cars: Horse Power vs Weight"
  const xAxisLabel = "Horsepower";
  const xValue = (d) => { 
      return d.horsepower 
    };
  const yAxisLabel = "Weight"
  const yValue = (d) =>{
  	return d.weight;
  };
  
  const margin = { top: 50, right: 40, bottom: 100, left: 170 };
	const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 10;
 
  const xScale = scaleLinear()
  	.domain(extent(data,xValue))
  	.range([0, innerWidth])
  	.nice(); //.nice makes grid lines end on a tick. 
  
  
  const yScale = scaleLinear()
  	.domain(extent(data,yValue))
  	.range([0, innerHeight])
  	.nice();
  
  //set svg margins 
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${50})`);
  

  const xAxis = axisBottom(xScale)
  								.tickSize(-innerHeight)
  								.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  								.tickSize(-innerWidth)
  								.tickPadding(10);  
    
	
  const yAxisG = g.append('g')
  	.call(yAxis);
  
  //remove tick
  yAxisG
  	.selectAll('.domain')
  	.remove();
  
    yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -93)
  	.attr('x', - innerHeight / 2)
  	.attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
          
          
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
    
  xAxisG.select('.domain',)
  	.remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 75)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue( d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class', 'title')
  	.text(title)
  	.attr('y', -10);
  
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data =>{
  	data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    })
    render(data);
  });